==> estateplat-common-1.2.4-20200910.011056-431-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxFyYwxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version 1.0, 2019/5/31
 * @description 法院业务信息
 */
@Table(name = "gx_fy_ywxx")
public class GxFyYwxx implements Serializable {
    @Id
    private String ywid;//主键id
    private String ywbm;//业务编码
    private String shzt;//审核状态 0:未审，1：已审，2：审核不通过
    private Date createtime;//创建时间
    private Date updatetime;//更新时间
    private String bh;//银行抵押编号
    private String shyj;//审核意见
    private String djzt;//登记状态，记录流程节点名称
    private String bdcbh;//不动产编号
    private String czr;//操作人
    private String bz;//备注
    private String spyj;//审批意见
    private String sjr;//收件人
    private String sjdz;//收件地址
    private Date sjsj;//收件时间
    private String dwdm;//单位代码

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getYwbm() {
        return ywbm;
    }

    public void setYwbm(String ywbm) {
        this.ywbm = ywbm;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getBdcbh() {
        return bdcbh;
    }

    public void setBdcbh(String bdcbh) {
        this.bdcbh = bdcbh;
    }

    public String getCzr() {
        return czr;
    }

    public void setCzr(String czr) {
        this.czr = czr;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSpyj() {
        return spyj;
    }

    public void setSpyj(String spyj) {
        this.spyj = spyj;
    }

    public String getSjr() {
        return sjr;
    }

    public void setSjr(String sjr) {
        this.sjr = sjr;
    }

    public String getSjdz() {
        return sjdz;
    }

    public void setSjdz(String sjdz) {
        this.sjdz = sjdz;
    }

    public Date getSjsj() {
        return sjsj;
    }

    public void setSjsj(Date sjsj) {
        this.sjsj = sjsj;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }
}

==> estateplat-common-1.2.4-20240702.040150-1240-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxFyYwxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version 1.0, 2019/5/31
 * @description 法院业务信息
 */
@Table(name = "gx_fy_ywxx")
public class GxFyYwxx implements Serializable {
    @Id
    private String ywid;//主键id
    private String ywbm;//业务编码
    private String shzt;//审核状态 0:未审，1：已审，2：审核不通过
    private Date createtime;//创建时间
    private Date updatetime;//更新时间
    private String bh;//银行抵押编号
    private String shyj;//审核意见
    private String djzt;//登记状态，记录流程节点名称
    private String bdcbh;//不动产编号
    private String czr;//操作人
    private String bz;//备注
    private String spyj;//审批意见
    private String sjr;//收件人
    private String sjdz;//收件地址
    private Date sjsj;//收件时间
    private String dwdm;//单位代码
    private String jyqd;// 交易渠道

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getYwbm() {
        return ywbm;
    }

    public void setYwbm(String ywbm) {
        this.ywbm = ywbm;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getBdcbh() {
        return bdcbh;
    }

    public void setBdcbh(String bdcbh) {
        this.bdcbh = bdcbh;
    }

    public String getCzr() {
        return czr;
    }

    public void setCzr(String czr) {
        this.czr = czr;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSpyj() {
        return spyj;
    }

    public void setSpyj(String spyj) {
        this.spyj = spyj;
    }

    public String getSjr() {
        return sjr;
    }

    public void setSjr(String sjr) {
        this.sjr = sjr;
    }

    public String getSjdz() {
        return sjdz;
    }

    public void setSjdz(String sjdz) {
        this.sjdz = sjdz;
    }

    public Date getSjsj() {
        return sjsj;
    }

    public void setSjsj(Date sjsj) {
        this.sjsj = sjsj;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getJyqd() {
        return jyqd;
    }

    public void setJyqd(String jyqd) {
        this.jyqd = jyqd;
    }
}
